<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_auv
// ** ne pas modifier le fichier **

return [

	// A
	'aide_non_disponible' => 'Aquela part de l’ajuda en linha es pas encara disponibla per aquesta lenga.',
	'avis_acces_interdit' => 'Accès proïbit.',
	'avis_article_modifie' => 'Atencion, @nom_auteur_modif@ a trabalhat sus aquel article quò fai @date_diff@ minutas',
	'avis_aucun_resultat' => 'Gran de resultat.',
	'avis_chemin_invalide_1' => 'Lo chamin qu’avètz chausit',
	'avis_chemin_invalide_2' => 'sembla pas valid. Volhatz tornar vèrs la pagina anteriora per verificar las informacions fornidas.',
	'avis_connexion_echec_1' => 'La connexion au servidor SQL a patracat.', # MODIF
	'avis_connexion_echec_2' => 'Tornatz vèrs la pagina anteriora, e verificatz las informacions qu’avètz fornidas.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Sus ben de servidors, devètz <b>demandar</b> qu’activen vòstre accès vèrs la basa SQL avans de la poder utilizar. Se vos podètz pas connectar, verificatz qu’ajatz be realizat aquel procediment.', # MODIF
	'avis_connexion_ldap_echec_1' => 'La connexion au servidor LDAP a patracat.',
	'avis_connexion_ldap_echec_2' => 'Tornatz a la pagina anteriora, e verificatz las informacions qu’avètz fornidas. ',
	'avis_connexion_ldap_echec_3' => 'Alternativament, utilizetz pas lo supòrt LDAP per importar d’utilizaires.', # MODIF
	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, voudretz be oschar aquela casa de confirmacion.',
	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
	'avis_espace_interdit' => '<b>Espaci proïbit</b><p>SPIP es ja installat.', # MODIF
	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion a pas pogut legir los noms de las basas de donadas installadas.',
	'avis_lecture_noms_bases_2' => 'Siá gran de basa es pas disponibla, siá la foncion que permet de teirar las basas es estada desactivada per de rasons de seguretat (quo es lo cas chas mai que d’un auberjador).',
	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, z-es probable qu’una basa que pòrta vòstre nom de login siá utilizabla:',
	'avis_non_acces_page' => 'Podètz pas accedir vèrs aquela pagina.',
	'avis_operation_echec' => 'L’operacion a patracat.',
	'avis_suppression_base' => 'ATENCION, suprimir las donadas z-es irreversible',

	// B
	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
	'bouton_ajouter' => 'Apondre',
	'bouton_demande_publication' => 'Demandar la publicacion d’aqueste article',
	'bouton_effacer_tout' => 'Esfaçar tot',
	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Afichar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tèira daus redactors connectats', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Mandar los anoncis a l’adreiça:',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tèira de las novetats',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Pas aparéisser dins la tèira daus redactors', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Pas mandar d’anoncis editoriaus',
	'bouton_redirection' => 'TORNAR DIRIGIR',
	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
	'bouton_suivant' => 'Seguent',
	'bouton_tenter_recuperation' => 'Assajar de reparar',
	'bouton_test_proxy' => 'Assajar lo proxy',
	'bouton_vider_cache' => 'Voidar l’escondedor',

	// C
	'cache_modifiable_webmestre' => 'Lo webmèstre dau sit pòt modificar aquestes paramètres.', # MODIF
	'calendrier_synchro' => 'S’utilizatz un logiciau d’agenda compatible <b>iCal</b>, lo podètz sincronizar amb las informacions d’aqueste sit.',

	// D
	'date_mot_heures' => 'oras',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Adreiça de l’annuari',
	'entree_adresse_email' => 'Vòstra adreiça e-mail',
	'entree_base_donnee_1' => 'Adreiça de la basa de donadas',
	'entree_base_donnee_2' => '(Sovent, aquela adreiça correspond a aquela de vòstre sit, de còps correspond a la mençon "localhost", de còps, se laissa voida completament.)',
	'entree_biographie' => 'Biografia brèva, en quauques mots.',
	'entree_chemin_acces' => '<b>Entrar</b> lo chamin d’accès:',
	'entree_cle_pgp' => 'Vòstra clau PGP',
	'entree_contenu_rubrique' => '(Contengut de la rubrica en quauques mots.)',
	'entree_identifiants_connexion' => 'Vòstres identificants de connexion...',
	'entree_informations_connexion_ldap' => 'Volhatz entrar dins aquel formulari las informacions de connexion a vòstre annuari LDAP.
L’administrator dau sistèma o de la ret vos deu poder fornir
 aquelas informacions.', # MODIF
	'entree_infos_perso' => 'Quau sètz?',
	'entree_interieur_rubrique' => 'Endins la rubrica:',
	'entree_liens_sites' => '<b>Liam ipertèxt</b> (referéncia, sit de vesitar...)',
	'entree_login' => 'Vòstre login',
	'entree_login_connexion_1' => 'Lo login de connexion',
	'entree_login_connexion_2' => '(Correspond de còps a vòstre login d’accès vèrs l’FTP; de còps se laissa voide)',
	'entree_mot_passe' => 'Vòstre senhal',
	'entree_mot_passe_1' => 'Senhal per la connexion',
	'entree_mot_passe_2' => '(Correspond de còps a vòstre senhal per l’FTP; de còps se laissa voide)',
	'entree_nom_fichier' => 'Volhatz entrar lo nom dau fichèir @texte_compresse@:',
	'entree_nom_pseudo' => 'Vòstre nom o vòstre pseudonim',
	'entree_nom_pseudo_1' => '(Vòstre nom o vòstre pseudonim)',
	'entree_nom_site' => 'Lo nom de vòstre sit',
	'entree_nouveau_passe' => 'Senhal novèl',
	'entree_passe_ldap' => 'Senhal',
	'entree_port_annuaire' => 'Lo numèro de pòrt de l’annuari',
	'entree_signature' => 'Signatura',
	'entree_titre_obligatoire' => '<b>Títol</b> [Obligatòri]<br />',
	'entree_url' => 'L’adreiça (URL) de vòstre sit',

	// I
	'ical_info1' => 'Aquela pagina mòstra de metòdes diferents per demorar en contacte amb la vida d’aquel sit.',
	'ical_info2' => 'Per téner mai d’informacions sobre aquelas tecnicas, esitetz pas de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'I a dos chalendèirs a la vòstra disposicion. Lo primèir es un plan dau sit qu’anóncia totes los articles publicats. Lo segond conten los anoncis editoriaus en mai de vòstres darrèirs messatges privats: vos es reservat gràcias a una clau personala, que la podètz modificar en tot moment en renovant vòstre senhal. ',
	'ical_methode_http' => 'Telecharjament',
	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
	'ical_texte_prive' => 'Aquel chalendèir, d’usatge estrictament personau, vos informa de l’activitat editoriala privada d’aquel sit (òbras e rendètz-vos personaus, articles e brèvas prepausats...).',
	'ical_texte_public' => 'Aquel chalendèir vos permet de seguir l’activitat publica d’aquel sit (articles e brèvas publicats).',
	'ical_texte_rss' => 'Podètz sindicar las novetats d’aqueste sit dins quin legidor de fichèirs que siá en format XML/RSS (Rich Site Summary). Z-es maitot lo format que permet a SPIP de legir las novetats publicadas dins d’autres sits en utilizar un format d’eschamge compatible (sit sindicats).  ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de corrèir',
	'ical_titre_rss' => 'Fichèirs «backend»',
	'icone_activer_cookie' => 'Activar lo cookie de correspondéncia',
	'icone_afficher_auteurs' => 'Afichar los autors',
	'icone_afficher_visiteurs' => 'Afichar los vesitaires',
	'icone_arret_discussion' => 'Quitar aquela discussion',
	'icone_calendrier' => 'Chalendèir',
	'icone_creer_auteur' => 'Crear un autor nuòu e l’associar a aquel article',
	'icone_creer_mot_cle' => 'Crear un mot clau nuòu e lo liar a aquel article',
	'icone_creer_rubrique_2' => 'Crear una rubrica nuòva',
	'icone_modifier_article' => 'Modificar aquel article',
	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’article',
	'icone_supprimer_cookie' => 'Suprimir lo cookie de correspondéncia',
	'icone_supprimer_rubrique' => 'Suprimir aquela rubrica',
	'icone_supprimer_signature' => 'Suprimir aquela signatura',
	'icone_valider_signature' => 'Validar aquela signatura',
	'image_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 article',
	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrá de passar aisat dau sit public au sit privat.',
	'info_administrateur' => 'Administrator', # MODIF
	'info_administrateur_1' => 'Administrator', # MODIF
	'info_administrateur_2' => 'dau sit(<i>d’utilizar amb precaucion</i>)',
	'info_administrateur_site_01' => 'Se sètz administrator/tritz dau sit, volhatz', # MODIF
	'info_administrateur_site_02' => 'clicar aquel liam',
	'info_administrateurs' => 'Administrators', # MODIF
	'info_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'info_adresse' => 'a l’adreiça:',
	'info_adresse_url' => 'Adreiça (URL) dau sit public',
	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
	'info_ajout_image' => 'Quand apondètz d’imatges coma estachaments junts a un article, SPIP pòt crear automaticament per vos de vinhetas (miniaturas) daus imatges inserits. Aquò permet per exemple de crear automaticament una galariá o un pòrtfòlio.',
	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
	'info_annonce_nouveautes' => 'Anonci de las novetats',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Los articles pòstdatats per paréisser',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Los articles d’aquel autor',
	'info_articles_trouves' => 'Articles trobats',
	'info_attente_validation' => 'Vòstres articles en apèita de validacion',
	'info_aujourdhui' => 'anuèit:',
	'info_auteurs' => 'Los autors',
	'info_auteurs_par_tri' => 'autors@partri@',
	'info_auteurs_trouves' => 'Autors trobats',
	'info_authentification_externe' => 'Autentificacion extèrna',
	'info_avertissement' => 'Avís',
	'info_base_installee' => 'L’estructura de vòstra basa de donadas z-es installada.',
	'info_chapeau' => 'Chapèl',
	'info_chapeau_2' => 'Chapèl:',
	'info_chemin_acces_1' => 'Opcions: <b>chamin d’accès dins l’annuari</b>',
	'info_chemin_acces_2' => 'Ara devètz configurar lo chamin d’accès vèrs las informacions dins l’annuari.', # MODIF
	'info_chemin_acces_annuaire' => 'Opcions:<b>chamin d’accès dins l’annuari',
	'info_choix_base' => 'Tresesma estapa:',
	'info_classement_1' => '<sup>èir</sup> de @liste@',
	'info_classement_2' => '<sup>nd</sup> de @liste@',
	'info_code_acces' => 'Oblidetz pas vòstres còdes d’accès pròpris!',
	'info_config_suivi' => 'S’aquela adreiça correspond a una lista de corrèir, podètz indicar çai sos l’adreiça ont los participants au sit se pòdon inscriure. Aquela adreiça pòt èstre una URL (per exemple la pagina d’inscripcion a la lista per lo web), o una adreiça e-mail tenent un subjècte especific (per exemple: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Vos podètz abonar a la lista de difusion d’aqueste sit. Adoncas recebretz per e-mail los anoncis d’articles e de brèvas que se prepausa a la publicacion.',
	'info_confirmer_passe' => 'Confirmar aquel senhal novèl:',
	'info_connexion_base' => 'Segonda estapa: <b>Assai de connexion a la basa</b>',
	'info_connexion_ldap_ok' => 'La connexion LDAP a abotit.</b><p> Podètz passar a l’estapa seguenta.</p>', # MODIF
	'info_connexion_mysql' => 'Primèira estapa:<b>Vòstra connexion SQL</b>',
	'info_connexion_ok' => 'La connexion a abotit.',
	'info_contact' => 'Contacte',
	'info_contenu_articles' => 'Contengut daus articles',
	'info_creation_paragraphe' => '(Per crear de paragrafs, sufís que laissetz de linhas voidas.)', # MODIF
	'info_creation_rubrique' => 'Avans de poder escriure d’articles,<br /> devètz crear per lo mens una rubrica.<br />',
	'info_creation_tables' => 'Quatresma estapa: <b>Creacion de las taulas de la basa</b>',
	'info_creer_base' => '<b>Crear</b> una basa de donadas novèla:',
	'info_dans_rubrique' => 'Dins la rubrica:',
	'info_date_publication_anterieure' => 'Data anteriora de publicacion:',
	'info_date_referencement' => 'DATA DE REFERENCIAMENT D’AQUEL SIT:',
	'info_derniere_etape' => 'Darrèira estapa: <b>Quo es ’chabat!',
	'info_descriptif' => 'Descriptiu:',
	'info_discussion_cours' => 'Discussions en cors',
	'info_ecrire_article' => 'Avans de poder escriure d’articles, vos chau crear per lo mens una rubrica.',
	'info_email_envoi' => 'Adreiça e-mail d’enviament (opcionau)',
	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar los e-mails (a fauta d’aquò, s’utilizará l’adreiça destinatari coma adreiça d’enviament):',
	'info_email_webmestre' => 'Adreiça e-mail dau responsable dau sit (opcionau)', # MODIF
	'info_envoi_email_automatique' => 'Enviament d’e-mails automatics',
	'info_envoyer_maintenant' => 'Mandar ara',
	'info_etape_suivante' => 'Passar a l’estapa seguenta',
	'info_etape_suivante_1' => 'Podètz passar a l’estapa seguenta.',
	'info_etape_suivante_2' => 'Podètz passar a l’estapa seguenta.',
	'info_exportation_base' => 'exportacion de la basa vèrs @archive@',
	'info_facilite_suivi_activite' => 'Per facilitar lo segut de l’activitat editoriala dau sit, SPIP vos pòt fornir per e-mail, per exemple a una lista de corrèir daus redactors, l’anonci de las demandas de publicacion e de las validacions d’articles.', # MODIF
	'info_fichiers_authent' => 'Fichèirs d’autentificacion « .htpasswd »',
	'info_forums_abo_invites' => 'Vòstre sit web ofrís de forums per los abonats; dins lo sit public los vesitaires son convidats a se registrar.', # MODIF
	'info_gauche_admin_tech' => '<b>A aquela pagina, mas los responsables dau sit lai pòdon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. Quauques unas implican un procès d’autentificacion especific, que necessita un accès FTP vèrs lo sit web.</p>', # MODIF
	'info_gauche_auteurs' => 'Trobaretz aicí totes los autors dau sit. La color de las icònas n’indica l’estatut (administrator = verd; redactor = jaune).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Los autors exteriors, sens accès vèrs lo sit, son indicats amb una icòna blava; los autors esfaçats amb un bordilhèir.', # MODIF
	'info_gauche_messagerie' => 'La messatjariá vos permet d’eschamjar de messatges entre redactors, de servar de mementos (per vòstre usatge personau) o d’afichar d’anoncis sus la pagina d’acuèlh de l’espaci privat (se sètz administrator/tritz).', # MODIF
	'info_gauche_statistiques_referers' => 'Aquela pagina presenta la lista daus <i>referidors</i>, quò vòu dire daus sits que contenon de liams que menan vèrs vòstre quite sit, mas unicament per ièr e anuèi lo jorn: aquela lista s’actualiza chasca 24 oras.',
	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí los vesitaires registrats
 dins l’espaci public dau sit (forums amb abonament).',
	'info_generation_miniatures_images' => 'Congreacion de miniaturas daus imatges',
	'info_hebergeur_desactiver_envoi_email' => 'Quauques auberjadors desactivan l’enviament automatic
 d’e-mails dempuèi lors servidors. En aquel cas, las foncionalitats seguentas
 d’SPIP foncionarán pas.',
	'info_hier' => 'ièr:',
	'info_identification_publique' => 'Vòstra identitat publica...',
	'info_image_process' => 'Volhatz seleccionar lo melhor metòde de fabricacion de las vinhetas en clicar sus l’imatge correspondent.',
	'info_image_process2' => '<b>N.B.</b> <i>Se pas un d’imatge apareis, lendonc lo servidor qu’aubèrja vòstre sit l’an pas configurat per utilizar d’aisinas talas. Se desiratz d’utilizar aquelas foncions, contactatz lo responsable tecnic e demandatz las extensions «GD» o «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imatges calculats automaticament',
	'info_informations_personnelles' => 'Cinquesma estapa: <b>Informacions personalas</b>',
	'info_inscription_automatique' => 'Inscripcion automatica de redactors novèls', # MODIF
	'info_jeu_caractere' => 'Jòc de caractèrs dau sit',
	'info_jours' => 'jorns',
	'info_laisser_champs_vides' => 'laissar aqueles champs voides)',
	'info_langues' => 'Lengas dau sit',
	'info_ldap_ok' => 'L’autentificacion LDAP z-es installada.',
	'info_lien_hypertexte' => 'Liam ipertèxt:',
	'info_liste_redacteurs_connectes' => 'Tèira daus redactors connectats', # MODIF
	'info_login_existant' => 'Aquel login ja existís.',
	'info_login_trop_court' => 'Login tròp cort.',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'Dins la mesma rubrica',
	'info_message_en_redaction' => 'Vòstres messatges en cors de redaccion',
	'info_message_technique' => 'Messatge tecnic:',
	'info_messagerie_interne' => 'Messatjariá intèrna',
	'info_mise_a_niveau_base' => 'Mesa a nivèl de vòstra basa SQL',
	'info_mise_a_niveau_base_2' => '{{Atencion!}} Avètz installada una version
  daus fichèirs SPIP {anteriora} a la que i aviá
  avans sobre aqueste sit: riscatz de pèrdre vòstra basa de donadas
   e vòstre sit foncionará pas mai.<br />{{Tornatz installar los
  fichèirs d’SPIP.}}',
	'info_modifier_rubrique' => 'Modificar la rubrica:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'Mon sit SPIP',
	'info_moyenne' => 'mejana:',
	'info_multi_cet_article' => 'Lenga d’aqueste article:',
	'info_multi_langues_choisies' => 'Volhatz seleccionar çai sos las lengas que son a posita daus redactors de vòstre sit.
  Las lengas ja emplejadas dins vòstre sit (afichadas primèiras) se pòdon pas desactivar.', # MODIF
	'info_multi_secteurs' => '... mas per las rubricas a la raiç dau sit?',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom dau destinatari',
	'info_nom_site' => 'Nom de vòstre sit',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
	'info_nombre_sites' => '@nb_sites@ sits,',
	'info_non_deplacer' => 'De pas desplaçar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pòt mandar, regularament, l’anonci de las darrèiras novetats dau sit
 (articles e brèvas publicats recentament).',
	'info_non_envoi_liste_nouveautes' => 'Pas mandar la tèira de las novetats',
	'info_non_modifiable' => 'se pòt pas modificar',
	'info_non_suppression_mot_cle' => 'vòle pas suprimir aquel mot clau.',
	'info_notes' => 'Nòtas',
	'info_nouvel_article' => 'Article nuòu',
	'info_nouvelle_traduction' => 'Revirada nuòva:',
	'info_numero_article' => 'ARTICLE NUMÈRO:',
	'info_obligatoire_02' => '[Obligatòri]', # MODIF
	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion daus vesitaires dau sit public', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires', # MODIF
	'info_options_avancees' => 'OPCIONS AVANÇADAS',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pagina proïbida',
	'info_par_nombre_article' => '(per nombre d’articles)',
	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
	'info_passes_identiques' => 'Los dos mots de santa Clara son pas identics.',
	'info_plus_cinq_car' => 'mai de 5 caractèrs',
	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
	'info_plus_trois_car' => '(mai de 3 caractèrs)',
	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_post_scriptum' => 'Post-scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'per',
	'info_preview_texte' => 'Z-es possible de previsualizar lo sit coma s’avián publicat totes los articles e brèvas (que tenon aumens l’estatut "prepausat"). La chau dobrir, aquela possibilitat, aus administrators solament, a totes los redactors, o a pas degun?', # MODIF
	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
	'info_procedure_maj_version' => 'Chau lançar la procedura d’actualizacion per adaptar
 la basa de donadas a la version novèla d’SPIP.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Vòstres articles publicats en linha',
	'info_question_accepter_visiteurs' => 'S’a las esqueletas de vòstre sit web se prevei lo registrament de vesitaires sens accès a l’espaci privat, volhatz activar l’opcion seguenta:', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptatz que de redactors novèls s’inscrivan
 a partir dau sit public? Se o acceptatz, los vesitaires se poirán inscriure
 gràcias a un formulari automatizat e doncas accedirán vèrs l’espaci privat per
 prepausar d’articles.<blockquote><i> Durant la fasa d’inscripcion, los utilizaires recebon un e-mail automatic
 que lor baila un còde d’accès vèrs lo sit privat.
Quauques auberjadors autorizan pas l’enviament d’e-mails dempuèi lors servidors: en aquel cas, l’inscripcion automatica z-es
 impossibla.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Raiç dau sit',
	'info_recharger_page' => 'Volhatz tornar charjar aquela pagina dins un momenton.',
	'info_recherche_auteur_zero' => '<b>Ges de resultat trobat per "@cherche_auteur@".',
	'info_recommencer' => 'Volhatz tornar començar.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'qu’accedís vèrs l’espaci privat (<i>recomandat</i>)',
	'info_redacteurs' => 'Redactors',
	'info_redaction_en_cours' => 'EN CORS DE REDACCION',
	'info_redirection' => 'Redireccion',
	'info_refuses' => 'Vòstres articles refusats',
	'info_reglage_ldap' => 'Opcions: <b>Reglatge de l’importacion LDAP</b>',
	'info_renvoi_article' => '<b>Redireccion.</b> Aquel article remanda a la pagina:',
	'info_reserve_admin' => 'Mas los administrators pòdon modificar aquela adreiça.', # MODIF
	'info_restreindre_rubrique' => 'Restrénher la gestion a la rubrica:',
	'info_resultat_recherche' => 'Resultats de la cèrcha:',
	'info_rubriques' => 'Rubricas',
	'info_rubriques_02' => 'rubricas',
	'info_rubriques_trouvees' => 'Rubricas trobadas',
	'info_sans_titre' => 'Sens títol',
	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sos lo chamin d’accès dins l’annuari:',
	'info_signatures' => 'signaturas',
	'info_site' => 'Sit',
	'info_site_2' => 'sit: ',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referenciat',
	'info_site_web' => 'SIT WEB:', # MODIF
	'info_sites' => 'sits',
	'info_sites_lies_mot' => 'Los sits referenciats liats a aquel mot clau',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sits trobats',
	'info_sous_titre' => 'Sostítol:',
	'info_statut_administrateur' => 'Administrator', # MODIF
	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatut predefinit daus utilizaires importats', # MODIF
	'info_statut_utilisateurs_2' => 'Chausissètz l’estatut d’atribuir a las personas presentas dins l’annuari LDAP quand se connèctan per lo primèir còp. Poiretz puèi modificar aquel estatut per chasque autor un cas per un.', # MODIF
	'info_suivi_activite' => 'Segut de l’activitat editoriala',
	'info_surtitre' => 'Sobretítol:',
	'info_taille_maximale_vignette' => 'Talha maximala de las vinhetas congreadas per lo sistèma:',
	'info_terminer_installation' => 'Ara podètz ’chabar la procedura d’installacion estandard.',
	'info_texte' => 'Tèxt',
	'info_texte_explicatif' => 'Tèxt explicatiu',
	'info_texte_long' => '(lo tèxt es long: apareis doncas en talhons distints que se tornarán empejar un còp validats.)',
	'info_texte_message' => 'Tèxt de vòstre messatge:', # MODIF
	'info_texte_message_02' => 'Tèxt dau messatge',
	'info_titre' => 'Títol:',
	'info_total' => 'totau: ',
	'info_tous_articles_en_redaction' => 'Totes los articles en cors de redaccion',
	'info_tous_articles_presents' => 'Totes los articles publicats dins aquela rubrica',
	'info_tous_les' => 'totes los:',
	'info_tout_site' => 'Tot lo sit ',
	'info_tout_site2' => 'Z-an pas revirat l’article vèrs aquela lenga.',
	'info_tout_site3' => 'Z-an revirat l’article vèrs aquela lenga, mas an portat puèi de modificacions a l’article de referéncia. Chau actualizar la revirada.',
	'info_tout_site4' => 'Z-an revirat l’article vèrs aquela lenga, e la revirada z-es actualizada.',
	'info_tout_site5' => 'Article originau.',
	'info_tout_site6' => '<b>Atencion:</b> mas los articles originaus s’afichan.
Las reviradas s’assòcian a l’originau,
una color indica lor estat:',
	'info_travail_colaboratif' => 'Trabalh collaboratiu sobre los articles',
	'info_un_article' => 'un article, ',
	'info_un_site' => 'un sit, ',
	'info_une_rubrique' => 'una rubrica, ',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL:',
	'info_urlref' => 'Liam ipertèxt:',
	'info_utilisation_spip' => 'Ara podètz començar d’utilizar lo sistèma de publicacion assistida...',
	'info_visites_par_mois' => 'Afichatge per mes:',
	'info_visiteur_1' => 'Vesitaire',
	'info_visiteur_2' => 'dau sit public',
	'info_visiteurs' => 'Vesitaires',
	'info_visiteurs_02' => 'Vesitaires dau sit public',
	'install_echec_annonce' => 'L’installacion patracará, o abotirá a un sit non foncionau...',
	'install_extension_mbstring' => 'SPIP fonciona pas amb:',
	'install_extension_php_obligatoire' => 'SPIP exigís l’extension php:',
	'install_select_langue' => 'Seleccionatz una lenga puèi clicatz lo boton « seguent » per ’modar la procedura d’installacion.',
	'intem_redacteur' => 'redactor',
	'item_accepter_inscriptions' => 'Acceptar las inscripcions',
	'item_activer_messages_avertissement' => 'Activar los messatges d’avertiment',
	'item_administrateur_2' => 'administrator', # MODIF
	'item_afficher_calendrier' => 'Afichar dins lo chalendèir',
	'item_choix_administrateurs' => 'los administrators', # MODIF
	'item_choix_generation_miniature' => 'Congrear automaticament las miniaturas daus imatges.',
	'item_choix_non_generation_miniature' => 'Pas congrear de miniaturas daus imatges.',
	'item_choix_redacteurs' => 'los redactors',
	'item_choix_visiteurs' => 'los vesitaires dau sit public',
	'item_creer_fichiers_authent' => 'Crear de fichèirs .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'aus articles',
	'item_mots_cles_association_rubriques' => 'a las rubricas',
	'item_mots_cles_association_sites' => 'aus sits referenciats o sindicats',
	'item_non' => 'Non pas',
	'item_non_accepter_inscriptions' => 'Pas acceptar las inscripcions',
	'item_non_activer_messages_avertissement' => 'Gran de messatge d’avertiment',
	'item_non_afficher_calendrier' => 'De pas afichar dins lo chalendèir',
	'item_non_creer_fichiers_authent' => 'Pas crear aqueles fichèirs',
	'item_non_publier_articles' => 'Pas publicar los articles avans la data de publicacion prevista.',
	'item_nouvel_auteur' => 'Autor nuòu',
	'item_nouvelle_rubrique' => 'Rubrica nuòva',
	'item_oui' => 'Òc be',
	'item_publier_articles' => 'Publicar los articles, quina que siá lor data de publicacion',
	'item_reponse_article' => 'Responsa a l’article',
	'item_visiteur' => 'vesitaire',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'Apondre aquel autor',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOM DAU SIT:',
	'lien_retirer_auteur' => 'Tirar l’autor',
	'lien_site' => 'sit',
	'lien_tout_deplier' => 'Desplejar tot',
	'lien_tout_replier' => 'Tornar plejar',
	'lien_trier_nom' => 'Triar per nom',
	'lien_trier_nombre_articles' => 'Triar per nombre d’articles',
	'lien_trier_statut' => 'Triar per estatut',
	'lien_voir_en_ligne' => 'VEIRE EN LINHA:',
	'logo_article' => 'LÒGO DE L’ARTICLE', # MODIF
	'logo_auteur' => 'LÒGO DE L’AUTOR', # MODIF
	'logo_rubrique' => 'LÒGO DE LA RUBRICA', # MODIF
	'logo_site' => 'LÒGO D’AQUEL SIT', # MODIF
	'logo_standard_rubrique' => 'LÒGO ESTANDARD DE LAS RUBRICAS', # MODIF
	'logo_survol' => 'LÒGO PER LO SOBREVÒU', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Chausida de vòstra basa',
	'module_fichier_langue' => 'Fichèir de lenga',
	'module_raccourci' => '’Corcha',
	'module_texte_affiche' => 'Tèxt afichat',
	'module_texte_explicatif' => 'Podètz inserir las ’corchas seguentas dins las esqueletas de vòstre sit public. Se revirarán automaticament  dins las diferentas lengas per las qualas existís un fichèir de lenga.',
	'module_texte_traduction' => 'Lo fichèir de lenga «@module@» z-es disponible en:',
	'mois_non_connu' => 'non conegut',

	// O
	'onglet_repartition_actuelle' => 'per lo temps que vai',

	// R
	'required' => '[Obligatòri]', # MODIF

	// S
	'statut_admin_restreint' => '(admin. restrent)', # MODIF

	// T
	'taille_cache_image' => 'Los imatges qu’SPIP a calculat automaticament (vinhetas daus documents, títols presentats en forma grafica, foncions matematicas en format TeX...) ocupan dins lo repertòri @dir@ un totau de @taille@.',
	'taille_cache_octets' => 'Ara la talha de l’escondedor compassa @octets@.', # MODIF
	'taille_cache_vide' => 'L’escondedor z-es voide.',
	'taille_repertoire_cache' => 'Talha dau repertòri escondedor',
	'text_article_propose_publication' => 'Article prepausat per la publicacion. Esitetz pas de donar vòstre vejaire gràcias au forum estachat a aquel article (en bas de pagina).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Quauques servidors LDAP accèptan ges d’accès anonim. En aquel cas, chau especificar un identificant d’accès iniciau per poder puèi cerchar d’informacions dins l’annuari. Pasmens, los champs seguents se poirán laissar voides dins lo pus mai daus cas.',
	'texte_admin_effacer_01' => 'Aquela comanda esfaça <i>tot</i> lo contengut de la basa de donadas,
 inclús <i>totes</i> los accès redactors e administrators. Un còp que l’auretz executada, auretz de tornar lançar l’installacion d’SPIP per tornar crear una basa novèla e mai un primèir accès administrator.', # MODIF
	'texte_adresse_annuaire_1' => '(Se vòstre annuari z-es installat sobre la mesma maquina qu’aquel sit web, s’agís probable de "localhost".)',
	'texte_ajout_auteur' => 'L’autor seguent es estat apondut a l’article:',
	'texte_annuaire_ldap_1' => 'S’accedissètz a un annuari (LDAP), lo podètz utilizar per importar automaticament d’utilizaires sos SPIP.', # MODIF
	'texte_article_statut' => 'Aquel article es:',
	'texte_article_virtuel' => 'Article virtuau',
	'texte_article_virtuel_reference' => '<b>Article virtuau:</b> article referenciat dins vòstre sit SPIP, mas redirigit vèrs una autra URL. Per suprimir la redireccion, esfaçatz l’URL çai sobre.',
	'texte_aucun_resultat_auteur' => 'Gran de resultat per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Aqueste sit vos pòt indicar de contunh la lista daus redactors connectats, çò que vos permet d’eschamjar de messatges en dirècte. Podètz decidir de pas aparéisser dins aquela lista (sètz "invisible/a" per los autres utilizaires).', # MODIF
	'texte_auteurs' => 'LOS AUTORS',
	'texte_choix_base_1' => 'Chausissètz vòstra basa:',
	'texte_choix_base_2' => 'Lo servidor SQL conten mai que d’una basa de donadas.',
	'texte_choix_base_3' => '<b>Chausissètz</b> çai sos aquela que vòstre auberjador vos a atribuida:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elements',
	'texte_connexion_mysql' => 'Consultatz las informacions que vòstre auberjador fornís: lai devètz trobar, se vòstre auberjador supòrta SQL, los còdes de connexion au servidor SQL.', # MODIF
	'texte_contenu_article' => '(Contengut de l’article en quauques mots.)',
	'texte_contenu_articles' => 'Segon la maqueta que vòstre sit a adoptada, podètz decidir
 que quauques elements daus articles s’utilizen pas.
 Utilizatz la tèira çai sos per indicar quins elements son disponibles.',
	'texte_crash_base' => 'Se vòstra basa de donadas a
 patracat, podètz assajar una reparacion
 automatica.',
	'texte_creer_rubrique' => 'Avans de poder escriure d’articles,<br /> devètz crear una rubrica.',
	'texte_date_creation_article' => 'DATA DE CREACION DE L’ARTICLE:',
	'texte_date_publication_anterieure' => 'DATA DE PUBLICACION ANTERIORA :',
	'texte_date_publication_anterieure_nonaffichee' => 'Afichar ges de data de publicacion anteriora.',
	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA :',
	'texte_descriptif_rapide' => 'Descriptiu rapid',
	'texte_effacer_base' => 'Esfaçar la basa de donadas SPIP',
	'texte_en_cours_validation' => 'Se prepausa de publicar los articles e brèvas çai sos. Esitetz pas per donar vòstre vejaire gràcias aus forums que lai son estachats.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Podètz enrichir la compaginacion de vòstre tèxt en utilizar de "’corchas tipograficas".',
	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichèirs especiaus  <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> dins lo repertòri @dossier@ ?</b><p>
  Aqueles fichèirs vos pòdon servir per restrénher l’accès aus autors
  e administrators endacòm mai dins vòstre sit
  (programa extèrne d’estadisticas, per exemple).<p>
 Se vos servís pas, podètz laissar aquesta opcion
  a sa valor predefinida (ges de creacion
  daus fichèirs).', # MODIF
	'texte_informations_personnelles_1' => 'Ara lo sistèma vos creará un accès personalizat au sit.',
	'texte_informations_personnelles_2' => '(Nòta: se s’agís d’una reïnstallacion, e se vòstre accès fonciona encara, podètz', # MODIF
	'texte_introductif_article' => '(Tèxt introductiu de l’article.)',
	'texte_jeu_caractere' => 'Aquesta opcion z-es utila se vòstre sit deu afichar d’alfabets
 diferents de l’alfabet latin (o "occidentau") e sos derivats.
 En aquel cas, vau mai chamjar lo reglatge predefinit per 
 un jòc de caractèrs apropriat. ’Ma que siá vos conselham de far d’assais
 per fin de trobar una solucion satisfasenta. Se modificatz aquel paramètre, oblidetz pas nimai d’adaptar
 lo sit public en consequéncia (balisa <tt>#CHARSET</tt>).',
	'texte_login_ldap_1' => '(Laissar voide per un accès anonim, o picar lo chamin complet, per exemple «<tt>uid=fabre, ou=usancèirs, dc=mon-domeni, dc=com</tt>».)',
	'texte_login_precaution' => 'Atencion! Quo es lo login amb lo quau sètz ara connectat/ada. 
 Utilizatz aqueste formulari amb precaucion...',
	'texte_mise_a_niveau_base_1' => 'Venètz d’actualizar los fichèirs SPIP.
 Ara chau metre a nivèl la basa de donadas
 dau sit.',
	'texte_modifier_article' => 'Modificar l’article:',
	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en mai que d’una lenga, amb una navigacion complèxa, podètz apondre un menut per chausir la lenga daus articles e/o de las rubricas, en foncion de l’organizacion de vòstre sit.', # MODIF
	'texte_multilinguisme_trad' => 'Podètz maitot activar un sistèma de gestion daus liams entre las diferentas reviradas d’un article.', # MODIF
	'texte_non_compresse' => '<i>non comprimit</i> (pr’amor que vòstre servidor supòrta pas aquela foncionalitat)',
	'texte_nouvelle_version_spip_1' => 'Avètz installada una version novèla d’SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se sètz webmèstre/webmèstra dau sit, volhatz esfaçar lo fichèir <tt>inc_connect.php3</tt> dau repertòri <tt>ecrire</tt> e tornar prene l’installacion a fin d’actualizar vòstres paramètres de connexion a la basa de donadas.<p> (NB: s’avètz eissubliat vòstres paramètres de connexion, agaitatz lo fichèir  <tt>inc_connect.php3</tt> avans de lo suprimir...)</p>', # MODIF
	'texte_operation_echec' => 'Tornatz a la pagina precedenta, chausissètz una autra basa o creatz-ne’n una novèla. Verificatz las informacions que vòstre auberjador a fornidas.',
	'texte_plus_trois_car' => 'mai de 3 caractèrs',
	'texte_plusieurs_articles' => 'Mai d’un autor trobat per "@cherche_auteur@":',
	'texte_port_annuaire' => '(La valor indicada coma predefinida conven en generau.)',
	'texte_proposer_publication' => 'Quand auretz ’chabat vòstre article,<br /> poiretz prepausar que siá publicat.',
	'texte_proxy' => 'Dins quauques cas (intranet, rets protegidas...),
  se pòt que chalha utilizar un <i>proxy HTTP</i> per aténher los sits sindicats.
  En aquel cas, marcatz çai sos son adreiça, sos la forma
  <tt><html>http://proxy:8080</html></tt>. En generau,
  laissaretz voida aquela casa.',
	'texte_publication_articles_post_dates' => 'Cossí SPIP se deu comportar fàcia aus articles que lor
  data de publicacion z-es fixada a una 
  eschaiença futura?',
	'texte_rappel_selection_champs' => '[Oblidetz pas de seleccionar aquel champ corrèctament.]',
	'texte_recalcul_page' => 'Se volètz
tornar calcular mas una pagina, passatz puslèu per l’espaci public e utilizatz lo  boton "tornar calcular".',
	'texte_recuperer_base' => 'Reparar la basa de donadas',
	'texte_reference_mais_redirige' => 'article referenciat dins vòstre sit SPIP, mas redirigit vèrs una autra URL.',
	'texte_requetes_echouent' => '<b>Quand quauques requistas SQL patracan
  sistematicament e sens rason aparenta, se pòt
  qu’aquò venha be ben de la basa de donadas.  </b><p>
  SQL ten la facultat de reparar sas
  taulas quand un accident las
 a escharvalhadas. Aicí podètz assajar aquela reparacion;
  s’abotís pas, servatz una còpia de l’afichatge, que conten
 benlèu d’indicis de çò que vai pas...<p>
  Se lo problèma persistís, contactatz vòstre
  auberjador.<p>', # MODIF
	'texte_selection_langue_principale' => 'Podètz seleccionar çai sos la "lenga principala" dau sit. Aquela chausida vos obliga pas -per fortuna- d’escriure vòstres articles dins la lenga seleccionada, mas permet de determinar:
 <ul><li> lo format predefinit de las datas sobre lo sit public;</li>
 <li> la natura dau motor tipografic que SPIP deu utilizar per lo rendut daus tèxts;</li>
 <li> la lenga utilizada dins los formularis dau sit public;</li>
 <li> la lenga presentada coma predefinida dins l’espaci privat.</li></ul>',
	'texte_sous_titre' => 'Sostítol',
	'texte_statistiques_visites' => '(barras escuras:  dimenge / corba escura: evolucion de la mejana)',
	'texte_statut_attente_validation' => 'en apèita de validacion',
	'texte_statut_publies' => 'publicats en linha',
	'texte_statut_refuses' => 'refusats',
	'texte_suppression_fichiers' => 'Utilizatz aquela comanda per suprimir totes los fichèirs que se tròban
dins l’escondedor SPIP. Aquò permet per exemple de forçar un calcul nuòu de totas las paginas
s’avètz bravament modificat lo grafisme o l’estructura dau sit.',
	'texte_sur_titre' => 'Sobretítol',
	'texte_table_ok' => ': aquesta taula z-es condreita.',
	'texte_tentative_recuperation' => 'Assai de reparacion',
	'texte_tenter_reparation' => 'Assajar de reparar la basa de donadas',
	'texte_test_proxy' => 'Per assajar aquel proxy, indicatz aicí l’adreiça d’un sit web
    que lo voudriatz esprovar.',
	'texte_titre_02' => 'Títol:',
	'texte_titre_obligatoire' => '<b>Títol</b> [Obligatòri]',
	'texte_travail_article' => '@nom_auteur_modif@ a trabalhat sus aquel article quò fai @date_diff@ minutas',
	'texte_travail_collaboratif' => 'Quand z-es frequent que mai d’un redactor 
  trabalhe sobre lo mesme article, lo sistèma
  pòt afichar los articles recentament "badats"
  a fin d’evitar las modificacions simultanèas.
  Aquela opcion z-es desactivada de manèira predefinida
  a fin d’evitar d’afichar de messatges d’avertiment
  intempestius.', # MODIF
	'texte_vide' => 'voide',
	'texte_vider_cache' => 'Voidar l’escondedor',
	'titre_admin_tech' => 'Mantenença tecnica',
	'titre_cadre_afficher_article' => 'Afichar los articles',
	'titre_cadre_afficher_traductions' => 'Afichar l’estat de las reviradas per las lengas seguentas:',
	'titre_cadre_ajouter_auteur' => 'APONDRE UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Endins la rubrica',
	'titre_cadre_numero_auteur' => 'AUTOR NUMÈRO',
	'titre_cadre_signature_obligatoire' => '<b>Signatura</b> [Obligatòria]<br />',
	'titre_config_fonctions' => 'Configuracion dau sit',
	'titre_configuration' => 'Configuracion dau sit',
	'titre_connexion_ldap' => 'Opcions: <b>Vòstra connexion LDAP</b>',
	'titre_groupe_mots' => 'GROP DE MOTS:',
	'titre_langue_article' => 'LENGA DE L’ARTICLE', # MODIF
	'titre_langue_rubrique' => 'LENGA DE LA RUBRICA', # MODIF
	'titre_langue_trad_article' => 'LENGA E REVIRADAS DE L’ARTICLE',
	'titre_les_articles' => 'LOS ARTICLES',
	'titre_naviguer_dans_le_site' => 'Navigar per lo sit...',
	'titre_nouvelle_rubrique' => 'Rubrica novèla',
	'titre_numero_rubrique' => 'RUBRICA NUMÈRO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Los articles',
	'titre_page_articles_tous' => 'Tot lo sit',
	'titre_page_calendrier' => 'Chalendèir @nom_mois@ de @annee@',
	'titre_page_config_contenu' => 'Configuracion dau sit',
	'titre_page_delete_all' => 'supression totala e irreversibla',
	'titre_page_recherche' => 'Resultats de la cèrcha @recherche@',
	'titre_page_statistiques_referers' => 'Estadisticas (liams entrants)',
	'titre_page_upgrade' => 'Mesa a nivèl d’SPIP',
	'titre_publication_articles_post_dates' => 'Publicacion daus articles pòstdatats',
	'titre_reparation' => 'Reparacion',
	'titre_suivi_petition' => 'Segut de las peticions',
	'trad_article_traduction' => 'Totas las versions d’aquel article:',
	'trad_delier' => 'Pas mai liar aqueste article a sas reviradas ', # MODIF
	'trad_lier' => 'Aqueste article es una revirada de l’article numèro:',
	'trad_new' => 'Escriure una revirada novèla d’aqueste article', # MODIF
];
